/*
KY-037 Sound Detection Sensor + Arduino
modified on 16 Apr 2019
by Mohammadreza Akbari @ Electropeak
https://electropeak.com/learn/

Modified by W.Elley April 2020 during coronavirus lockdown, for use as a school workshop sound level warning meter
*/

#include <FastLED.h> //load the LED control library

//assign a pin to the LED strip & tell the FastLED software how many LEDs the LED strip has
#define LED_PIN     6  
#define NUM_LEDS    10

CRGB leds[NUM_LEDS]; //the LED strip is represented as an array of CRGB colors, one color for each LED pixel.

int sensor_value = 0; //create a variable for the analogue A0 pin output & assign to it a starting value
int threshold = 513; //Enter Your threshold value here using calibration software to read the serial output (test KY-037 sensor gave 513 at calibration)
                      // use the following website for guidance on the calibration - https://create.arduino.cc/projecthub/electropeak/how-to-use-ky-037-sound-detection-sensor-with-arduino-a757a7
int abs_value = 0; //create another variable to take into account the 0-1023 range of the anaologue pins of the UNO

//establish the type of LED strip we are using & start the serial port output
void setup() {
  
  FastLED.addLeds<WS2812, LED_PIN, GRB>(leds, NUM_LEDS);   
  Serial.begin(9600); // setup serial

}

void loop() {
sensor_value = analogRead(A0); //begin reading the A0 pin values
abs_value = abs(sensor_value - threshold); //begin calculating the absolute values

for (int i = 0; i < NUM_LEDS; i++) {
  
// note that the fixed values below will change with different power sources as mobile phone chargers have similar voltages but differing amp outputs
// you can either change the numbers as you calibrate or alternately adjust the potentiometer on the KY-037 sensor, or both

// if the absolute value is less than 'x',turn the pin for this element on, i.e. green, safe
if (abs_value < 8) {
  leds[i] = CRGB (0, 255, 0);
  FastLED.show();
  Serial.println(abs_value); //this outputs the abs_value to the serial monitor - click it & see what your values are (icon at top right)
 }
// turn all pins blue within this fixed range, i.e. sound level is getting unsafe:
else if (abs_value >= 8 && abs_value <= 14) {
  leds[i] = CRGB (0, 0, 255);
  FastLED.show();
    }

// if neither of the two conditions above are true (i.e. abs_value is higher), turn all pins red    
else  {
  leds[i] = CRGB (255, 0, 0);
  FastLED.show();
   }
  

}
}

  
  
